* =======================PROGRAM: IQI_ALL_CONTROL.SAS ========================;
*  VERSION: AHRQ QI v7.0.1 BETA
*  RELEASE DATE: DECEMBER 2017
* ============================================================================;
 * The Inpatient Quality Indicator (IQI) module of the AHRQ Quality
   Indicators software includes the following programs:
   
   1. IQI_ALL_CONTROL.SAS    Assigns user inputs required by other programs
                       and designates output features.  
                  
   2. IQI_ALL_FORMATS.SAS    Creates SAS format library used by other programs.

   3. IQI_ALL_MEASURES.SAS   Assigns Inpatient Quality Indicators to 
                             inpatient records.

   4. IQI_PROV_OBSERVED.SAS Calculates observed rates for provider level Inpatient Quality Indicators.


 * The software also requires the following files:
 
   1. discharges.sas7bdat  User supplied discharge level file organized according 
                     to the layout in the software instructions.
                     The file name is up to the user but must be listed below.
                     
   2. IQI_Dx_Px_Macros.SAS Standard processes used by the other SAS programs.
                            The user does not need to open.

***************************************************************************** ;
******************************* PLEASE READ ********************************* ;
***************************************************************************** ;
 * The AHRQ Quality Indicator software is intended for use with discharges
   coded according to the standards in place at the date of the discharge. 
   Discharges should be classified under the ICD-10-CM/PCS specifications 
   effective 10/1/2015. All diagnosis codes require a corresponding Present
   on Admission, POA, value coded according to UB04 standards. 
   Although results can be generated with inputs coded under ICD9 and 
   converted to ICD10 with General Equivalence Mappings, the mapping process
   may produce unrepresentative results. ICD10 observed rate calculations
   should not be used to produce ICD9 risk adjusted outputs.
   
 * The USER MUST modify portions of the following code in order to
   run this software.  With one exception (see NOTE immediately
   following this paragraph), the only changes necessary to run
   this software are changes in this program (IQI_ALL_CONTROL.SAS). 
   The modifications include such items as specifying the name and location
   of the input data set, the year of population data to be used, and the 
   name and location of output data sets.
 
 * NOTE:  IQI_ALL_CONTROL.SAS provides the option to read data in and write 
          data out to different locations.  For example, "libname INMSR" points
        to the location of the input data set for the IQI_ALL_MEASURES program
        and "libname OUTMSR" points to the location of the output data set
        created by the IQI_ALL_MEASURES program. The location and file name of 
        each input and output can be assigned separately below. The default 
        values will place output in a SASData folder with standard names for
        each file based on the location of the IQI folder listed in the 
        PATHNAME variable.
        
 * NOTE:  In the other programs included with this package there is a 
        line of code that begins with "filename CONTROL".  
        The USER MUST include after "filename CONTROL" the location
        of the IQI_ALL_CONTROL.SAS file.

 Generally speaking, a first-time user of this software would proceed 
 as outlined below:

    1.  Modify and save IQI_ALL_CONTROL.SAS. (This program - MUST be done.)
    2.  Open IQI_ALL_FORMATS.SAS and specify location (path name) of
        IQI_ALL_CONTROL.SAS. (MUST be done.)
    3.  Run IQI_ALL_FORMATS.SAS. (MUST be done.) 
    4.  Open IQI_ALL_MEASURES.SAS and specify location of IQI_ALL_CONTROL.SAS
      program. (MUST be done.)
    5.  Run IQI_ALL_MEASURES.SAS. (MUST be done.)
    6.  To calculate observed rates for Provider level Inpatient 
      Quality Indicators:
         a.  Open IQI_PROV_OBSERVED.SAS and specify location
             of IQI_ALL_CONTROL.SAS program. (MUST be done.) 
         b.  Run IQI_PROV_OBSERVED.SAS. (MUST have run IQI_ALL_MEASURES.SAS.)


 * ---------------------------------------------------------------- ;
 * ---                 INPUTS FOR ALL PROGRAMS                  --- ;
 * ---------------------------------------------------------------- ;

*PATHNAME specifies the location of the IQI folder which includes the
          Programs, Macros, and SASdata subfolders;
%LET PATHNAME=c:\pathname\IQI;                   *<===USER MUST modify;
*DISFOLDER specifies the folder that contains the discharge data;
%LET DISFOLDER=c:\pathname;                      *<===USER MUST modify;
*DISCHARGE specifies the name of the discharge data file;
%LET DISCHARGE=discharges;                       *<===USER MUST modify;
*SUFX specifies an identifier suffix to be placed on output datasets;
%LET SUFX = v7_ICD10;                             *<===USER may modify;

*LIBRARY is where formats generated by IQI_ALL_FORMATS will be saved.;   
libname LIBRARY  "&PATHNAME.\SASData";                  *<===USER may modify;

 * ---------------------------------------------------------------- ;
 * --- INDICATE IF RECORDS SHOULD BE PRINTED IN SAS OUTPUT AT   --- ;
 * --- END OF EACH PROGRAM.  0 = NO, 1 = YES                    --- ;
 * ---------------------------------------------------------------- ;
%LET PRINT = 0;                                 *<===USER may modify;
 * ---------------------------------------------------------------- ;
 * --- ADD OPTIONS TO COMPRESS OUTPUT AND SUPPRESS SOURCE CODE  --- ;
 * --- IN LOG. RECOMMENDED WITH LARGE FILES. TO RESTORE RUN:    --- ;
 * --- options source compress = no                             --- ;
 * ---------------------------------------------------------------- ;
options compress = YES;
 * ---------------------------------------------------------------- ;
 * --- SET LOCATION OF SAS MACRO LIBRARY                        --- ;
 * ---------------------------------------------------------------- ;
filename MacLib "&PATHNAME.\Macros\" ;          *<===USER may modify;
 * ---------------------------------------------------------------- ;
 * ---              PROGRAM: IQI_ALL_MEASURES.SAS               --- ;
 * ---------------------------------------------------------------- ;
 * ---------------------------------------------------------------- ;
 * --- SET LOCATION OF IQI_ALL_MEASURES.SAS INPUT DATA          --- ;
 * ---------------------------------------------------------------- ;
libname INMSR  "&DISFOLDER.";                    *<==USER may modify;
 * ---------------------------------------------------------------- ;
 * --- SET LOCATION OF IQI_ALL_MEASURES.SAS OUTPUT DATA         --- ;
 * ---------------------------------------------------------------- ;
libname OUTMSR "&PATHNAME.\SASdata";             *<==USER may modify;
 * --- SET NAME OF OUTPUT FILE FROM IQI_ALL_MEASURES.SAS        --- ;
%LET OUTFILE_MEAS = IQMSR_&SUFX;                *<===USER may modify;
 * ---------------------------------------------------------------- ;
 * --- MODIFY INPUT AND OUTPUT FILE                             --- ;
 * ---------------------------------------------------------------- ;
 * --- PROGRAM DEFAULT ASSUMES THERE ARE                        --- ;
 * ---     35 DIAGNOSES (DX1-DX35)                              --- ;
 * ---     30 PROCEDURES (PR1-PR30)                             --- ;
 * ---------------------------------------------------------------- ;
 * --- MODIFY NUMBER OF DIAGNOSIS AND PROCEDURE VARIABLES TO    --- ;
 * --- MATCH USER DISCHARGE INPUT DATA                          --- ;
 * ---------------------------------------------------------------- ;
%LET NDX = 35;                                  *<===USER MUST modify;
%LET NPR = 30;                                  *<===USER MUST modify;
 * ---------------------------------------------------------------- ;
 * - INDICATE IF DATA AVAILABLE REGARDING NUMBER OF DAYS        --- ;
 * - FROM ADMISSION TO SECONDARY PROCEDURES                     --- ;
 * - 0 = PRDAY IS NOT INCLUDED, 1 = PRDAY IS INCLUDED           --- ;
 * ---------------------------------------------------------------- ;
%LET PRDAY  = 1;                                *<===USER may modify; 

 * ---------------------------------------------------------------- ;
 * - CREATE PERMANENT SAS DATASET TO STORE RECORDS THAT WILL    --- ;
 * - NOT BE INCLUDED IN CALCULATIONS BECAUSE KEY VARIABLE       --- ;
 * - VALUES ARE MISSING.  THIS DATASET SHOULD BE REVIEWED AFTER --- ;
 * - RUNNING IQI_ALL_MEASURES.SAS.                              --- ;
 * ---------------------------------------------------------------- ;
%LET DELFILE  = IQI_DELETED_&SUFX.;             *<===USER may modify;

 * =================================================================;
 * ============PROVIDER-LEVEL INPATIENT QUALITY INDICATORS==========;
 * =================================================================;
 * ---       PROGRAM: IQI_PROV_OBSERVED.SAS                     --- ;
 * ---------------------------------------------------------------- ;
 * ---------------------------------------------------------------- ;
 * --- SET LOCATION OF IQI_PROV_OBSERVED.SAS OUTPUT DATA        --- ;
 * ---------------------------------------------------------------- ;
libname OUTPOBS "&PATHNAME.\SASdata";           *<===USER may modify;

 * ---------------------------------------------------------------- ;
 * --- TYPELVLP indicates the levels (or _TYPE_) of             --- ;
 * --- summarization to be kept in the output.                  --- ;
 * ---                                                          --- ;
 * ---  TYPELVLP      stratification                            --- ;
 * ---  --------  ------------------------------------          --- ;
 * ---     0      overall                                       --- ;
 * ---     1                                      race          --- ;
 * ---     2                              payer                 --- ;
 * ---     3                              payer * race          --- ;
 * ---     4                        sex                         --- ;
 * ---     5                        sex         * race          --- ;
 * ---     6                        sex * payer                 --- ;
 * ---     7                        sex * payer * race          --- ;
 * ---     8                  age                               --- ;
 * ---     9                  age               * race          --- ;
 * ---    10                  age       * payer                 --- ;
 * ---    11                  age       * payer * race          --- ;
 * ---    12                  age * sex                         --- ;
 * ---    13                  age * sex         * race          --- ;
 * ---    14                  age * sex * payer                 --- ;
 * ---    15                  age * sex * payer * race          --- ;
 * ---    16       provider                                     --- ;
 * ---    17       provider                     * race          --- ;
 * ---    18       provider             * payer                 --- ;
 * ---    19       provider             * payer * race          --- ;
 * ---    20       provider       * sex                         --- ;
 * ---    21       provider       * sex         * race          --- ;
 * ---    22       provider       * sex * payer                 --- ;
 * ---    23       provider       * sex * payer * race          --- ;
 * ---    24       provider * age                               --- ;
 * ---    25       provider * age               * race          --- ;
 * ---    26       provider * age       * payer                 --- ;
 * ---    27       provider * age       * payer * race          --- ;
 * ---    28       provider * age * sex                         --- ;
 * ---    29       provider * age * sex         * race          --- ;
 * ---    30       provider * age * sex * payer                 --- ;
 * ---    31       provider * age * sex * payer * race          --- ;
 * ---                                                          --- ;
 * --- The default TYPELVLP (0,16) will provide an overall      --- :
 * --- and provider-level totals. If stratifications includes   --- ;
 * --- Age and/or Sex, be aware that the numerical results for  --- ;
 * --- non-Age/Sex categories will be incorrect.                --- ;
 * ---------------------------------------------------------------- ;
%LET TYPELVLP = IN (0,16);             *<===USER may modify;

 * ------------------------------------------------------------------ ;
 * --- NAME SAS DATASET OUTPUT FROM PROGRAM IQI_PROV_OBSERVED.SAS --- ;
 * --- SUMMARY OUTPUT FILE OF OBSERVED PROVIDER RATES.            --- ;
 * ------------------------------------------------------------------ ;
%LET  OUTFILE_PROVOBS  = IQPO_&SUFX.;         *<===USER may modify;
 * ------------------------------------------------------------------ ;
 * --- INDICATE IF A COMMA-DELIMITED FILE SHOULD BE GENERATED FOR --- ;
 * --- EXPORT INTO A SPREADSHEET. 0 = NO, 1 = YES.                --- ;
 * ------------------------------------------------------------------ ;
%LET TXTPOBS=0;                                   *<===USER may modify;

 * ---------------------------------------------------------------- ;
 * --- IF YOU CREATE A COMMA-DELIMITED FILE, SPECIFY THE LOCATION - ;
 * --- OF THE FILE.                                             --- ;
 * ---------------------------------------------------------------- ;
filename IQTXTPOB "&PATHNAME.\SASdata\IQPO_&SUFX..TXT";  *<===USER may modify;
************************* END USER INPUT ************************** ;
