*===================== PROGRAM: PQI09_ALL_FORMATS.SAS =======================;
*
*  DESCRIPTION: Creates Format library for AHRQ Pediatric Quality Indicator 09
*
*  VERSION: AHRQ QI v7.0.1 BETA
*  RELEASE DATE: DECEMBER 2017
* ============================================================================;

*PATHNAME specifies the location of the PQI09 folder which includes the
Programs, Macros, and SASdata subfolders;
%LET PATHNAME=C:\Pathname\PQI09;                         *<==USER MUST modify;
 
filename CONTROL "&PATHNAME.\Programs\PQI09_ALL_CONTROL.SAS";
 
%INCLUDE CONTROL;
  
proc format library=LIBRARY;
 
/* -------------------------------------------------------------- */
/* --- FORMATS FOR STRATIFIERS ---------------------------------- */
/* -------------------------------------------------------------- */
 
/* --- FORMAT FOR SEX CATEGORY ---------------------------------- */
value SEXCAT
1 = 'Male'
2 = 'Female'
;
 
/* --- FORMAT FOR RACE CATEGORY --------------------------------- */
value RACECAT
1 = 'White'
2 = 'Black'
3 = 'Hispanic'
4 = 'Asian and NH/PI'
5 = 'Amer Indian/AN'
6 = 'Other'
;
 
/* --- FORMAT FOR POPULATION CATEGORY ----------------------------- */
value POPCAT
1 = '0 to 4'
2 = '5 to 9'
3 = '10 to 14'
4 = '15 to 17'
;
 
/* --- FORMAT FOR AGE STRATIFIERS --------------------------------- */
 
value AGEFMT
low - 4 = 1
5 -  9 = 2
10 - 14 = 3
15 - 17 = 4
18 - 24 = 5
25 - 29 = 6
30 - 34 = 7
35 - 39 = 8
40 - 44 = 9
45 - 49 = 10
50 - 54 = 11
55 - 59 = 12
60 - 64 = 13
65 - 69 = 14
70 - 74 = 15
75 - 79 = 16
80 - 84 = 17
85 - high = 18;

* -------------------------------------------------------------- ;
* --- PQI09 DEFINING FORMATS ----------------------------------- ;
* -------------------------------------------------------------- ;

/* Diagnosis codeset ACSLBWD last updated 160922 for IDC10 v60rev3 */
Value $ACSLBWD
"P0501" = "1" /* Newborn light for gestational age, less than 500 grams */
"P0502" = "1" /* Newborn light for gestational age, 500-749 grams */
"P0503" = "1" /* Newborn light for gestational age, 750-999 grams */
"P0504" = "1" /* Newborn light for gestational age, 1000-1249 grams */
"P0505" = "1" /* Newborn light for gestational age, 1250-1499 grams */
"P0506" = "1" /* Newborn light for gestational age, 1500-1749 grams */
"P0507" = "1" /* Newborn light for gestational age, 1750-1999 grams */
"P0508" = "1" /* Newborn light for gestational age, 2000-2499 grams */
"P0511" = "1" /* Newborn small for gestational age, less than 500 grams */
"P0512" = "1" /* Newborn small for gestational age, 500-749 grams */
"P0513" = "1" /* Newborn small for gestational age, 750-999 grams */
"P0514" = "1" /* Newborn small for gestational age, 1000-1249 grams */
"P0515" = "1" /* Newborn small for gestational age, 1250-1499 grams */
"P0516" = "1" /* Newborn small for gestational age, 1500-1749 grams */
"P0517" = "1" /* Newborn small for gestational age, 1750-1999 grams */
"P0518" = "1" /* Newborn small for gestational age, 2000-2499 grams */
"P0700" = "1" /* Extremely low birth weight newborn, unspecified weight */
"P0701" = "1" /* Extremely low birth weight newborn, less than 500 grams */
"P0702" = "1" /* Extremely low birth weight newborn, 500-749 grams */
"P0703" = "1" /* Extremely low birth weight newborn, 750-999 grams */
"P0710" = "1" /* Other low birth weight newborn, unspecified weight */
"P0714" = "1" /* Other low birth weight newborn, 1000-1249 grams */
"P0715" = "1" /* Other low birth weight newborn, 1250-1499 grams */
"P0716" = "1" /* Other low birth weight newborn, 1500-1749 grams */
"P0717" = "1" /* Other low birth weight newborn, 1750-1999 grams */
"P0718" = "1" /* Other low birth weight newborn, 2000-2499 grams */
Other = "0"
;

/* Diagnosis codeset LIVEB2D last updated 160922 for IDC10 v60rev3 */
Value $LIVEB2D
"Z381" = "1" /* Single liveborn infant, born outside hospital */
"Z384" = "1" /* Twin liveborn infant, born outside hospital */
"Z387" = "1" /* Other multiple liveborn infant, born outside hospital */
Other = "0"
;

/* Diagnosis codeset LIVEBND last updated 160922 for IDC10 v60rev3 */
Value $LIVEBND
"Z3800" = "1" /* Single liveborn infant, delivered vaginally */
"Z3801" = "1" /* Single liveborn infant, delivered by cesarean */
"Z3830" = "1" /* Twin liveborn infant, delivered vaginally */
"Z3831" = "1" /* Twin liveborn infant, delivered by cesarean */
"Z3861" = "1" /* Triplet liveborn infant, delivered vaginally */
"Z3862" = "1" /* Triplet liveborn infant, delivered by cesarean */
"Z3863" = "1" /* Quadruplet liveborn infant, delivered vaginally */
"Z3864" = "1" /* Quadruplet liveborn infant, delivered by cesarean */
"Z3865" = "1" /* Quintuplet liveborn infant, delivered vaginally */
"Z3866" = "1" /* Quintuplet liveborn infant, delivered by cesarean */
"Z3868" = "1" /* Other multiple liveborn infant, delivered vaginally */
"Z3869" = "1" /* Other multiple liveborn infant, delivered by cesarean */
Other = "0"
;

Run;
